@@ -10,7 +10,7 @@ import re
 import traceback
 from pathlib import Path
 from typing import Any, List, Optional
-# from importlib import import_module
+from importlib import import_module
 from contextlib import redirect_stdout
 
 import click
@@ -29,6 +29,12 @@ if sys.version_info < (3, 6, 1):
     exit(code=1)
 
 
+# monkey patch sys.path to test modules run features without building the package
+# Shouldn't have any impact
+cwd = str(Path().resolve())
+if cwd not in sys.path:
+    sys.path.insert(0, cwd)
+
 cli = typer.Typer()
 
 
@@ -275,7 +281,7 @@ def cli_db_revision(
     ),
     sql: bool = typer.Option(
         False,
-        "-sql",
+        "--sql",
         help="Whether to dump the script out as a SQL string; when specified, the script is dumped to stdout.",
     ),
     head: str = typer.Option(
@@ -830,5 +836,20 @@ def cli_projet_init(
     typer.echo(f"\nDon't forget to edit `{project_path / '.env'}` !")
 
 
+cli_modules_run = typer.Typer(
+    name="run",
+    help="Run your module CLI.",
+    short_help="Run your module CLI.",
+)
+cli_modules.add_typer(cli_modules_run)
+
+
+for cli_file in Path("modules").glob("*/cli.py"):
+    if cli_file.is_file():
+        module_path = ".".join(cli_file.parts[:-1] + (cli_file.stem,))
+        module = import_module(module_path)
+        cli_modules_run.add_typer(module.cli, name=cli_file.parent.parts[-1])
+
+
 if __name__ == "__main__":
     cli()
